..
    This file is part of pytest-invenio.
    Copyright (C) 2018 CERN.

    pytest-invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

.. _fixtures:

Fixtures
--------
.. automodule:: pytest_invenio.fixtures
   :members:


Plugin
------
.. automodule:: pytest_invenio.plugin
   :members:
